#!/bin/sh
#
#

source /usr/local/bin/functions.sh

dir_webdav="/var/www/innovaphone/webdav/install"
dir_tmp_webdav="/var/www/innovaphone/webdav/install/tmp"
log_script=$1

exec &>$1

myPID=$(ps -efwww | grep -i install_script.sh | grep -v grep | awk {'print $2'} | head -1)

if [[ $EUID -ne 0 ]]; then
    throw_error "This script must be run as root $EUID" $log_script
fi

echo "Start install script: $myPID" > $log_script

# bash check if directory exists
# while true; do
if [ -d $dir_webdav ]; then
    cd $dir_webdav
    install_tars=( $(ls -l | egrep -oe 'install\.tar\.gz') )
    num_tars=${#install_tars[@]}
    if [ "$num_tars" -eq "1" ]; then
        install_tar=${install_tars[0]}
        log_msg "New package available: $install_tar" $log_script
        r_install_gz=`gzip -t $install_tar`
        r_install_tar=`gzip -l $install_tar | egrep -oe 'install\.tar'`
        if [ ${#r_install_gz} -eq "0" -a ${#r_install_tar} -gt "0" ]; then
            dir_tmp_webdav=`mktemp -d ./$(basename $0).XXXXXX`
            if [ $? -ne 0 ]; then
                throw_error "Can't create temp dir, exiting..." $log_script
            fi
            tar xvzf $install_tar -C $dir_tmp_webdav >> $log_script
            cd $dir_tmp_webdav
            # add permissions to files with empty permissions
            find . -perm 0000 | xargs chmod 0700
            # find install script
            install_exes=( $(ls install*.*) )
            num_exes=${#install_exes[@]}
            major=`cat /var/www/innovaphone/majorversion`
            majorapp=1
            if [ -f "majorversion" ]; then
                majorapp=`cat majorversion`
            fi
            if [ "${major}" != "${majorapp}" ]; then
                log_error "Linux Application Platform is V$major, so you can't install an application for V$majorapp" $log_script
                cd ..
                sleep 5s
                rm -f $dir_webdav/$install_tar
                rm -f $dir_webdav/install.tar.gz
                rm -rf $dir_tmp_webdav
            elif [ "$num_exes" -eq "1" ]; then
                install_exe=${install_exes[0]}
                if [ ! -x $install_exe ]; then
                    log_msg "Change mod(755) of $install_exe" $log_script
                    chmod 755 $install_exe
                fi
                ./$install_exe
                php5 /var/www/innovaphone/update_packages.php
                sleep 5s
                rm -f $dir_webdav/$install_tar
                rm -f $dir_webdav/install.tar.gz
                rm -f $dir_tmp_webdav/$install_exe
                cd $dir_webdav
                rm -rf $dir_tmp_webdav

                tmp_rotate="${TMPDIR:=/tmp}/appl_install_rotate_$$"
                trap 'rm -f "$tmp_rotate" >/dev/null 2>&1' 0
                trap "exit 2" 1 2 3 13 15
                echo "$log_script" > $tmp_rotate
                echo "{
                    rotate 8
                    missingok
                    notifempty
                    delaycompress
                    compress
                    create 754 www-data www-data
                    su root root
                }" >> $tmp_rotate
                logrotate -f $tmp_rotate

                echo "Start install script: $myPID" > $log_script
            else
                log_error "$install_sh script not available in $dir_tmp_webdav/$install_tar" $log_script
                cd ..
                sleep 5s
                rm -f $dir_webdav/$install_tar
                rm -f $dir_webdav/install.tar.gz
                rm -rf $dir_tmp_webdav
            fi
        else
            sleep 5s
            rm -f $dir_webdav/$install_tar
            rm -f $dir_webdav/install.tar.gz
            log_error "$install_exe script uncompleted" $log_script
        fi
    fi
else
    log_msg "Directory does not exists" $log_script
fi
# sleep 15s
# done
exit 1
